==> openbot-1.0.0-sources.jar: ai/engagely/openbot/model/repositories/impl/AppLanguageRepository.kt <==
package ai.engagely.openbot.model.repositories.impl

import ai.engagely.openbot.model.localstorage.SimpleKeyValueStorage
import ai.engagely.openbot.model.repositories.LanguageRepository
import kotlinx.coroutines.CoroutineDispatcher
import kotlinx.coroutines.withContext

class AppLanguageRepository(
    private val dispatcher: CoroutineDispatcher,
    private val simpleKeyValueStorage: SimpleKeyValueStorage
) : LanguageRepository {

    override suspend fun setDefaultLanguage(languageCode: String) {
        withContext(dispatcher) {
            simpleKeyValueStorage.storeStringDataForKey(
                LanguageRepository.KEY_DEFAULT_LANGUAGE,
                languageCode
            )
        }
    }

    override suspend fun setCurrentLanguage(languageCode: String) {
        withContext(dispatcher) {
            updatePreviousWithCurrent()
            simpleKeyValueStorage.storeStringDataForKey(
                LanguageRepository.KEY_CURRENT_LANGUAGE,
                languageCode
            )
        }
    }

    override suspend fun updatePreviousWithCurrent() {
        getCurrentLanguage()?.let { currentLanguage ->
            simpleKeyValueStorage.storeStringDataForKey(
                LanguageRepository.KEY_PREVIOUS_LANGUAGE,
                currentLanguage
            )
        }
    }

    override suspend fun getCurrentLanguage(): String? {
        return withContext(dispatcher) {
            simpleKeyValueStorage.readStringDataForKey(LanguageRepository.KEY_CURRENT_LANGUAGE)
                ?: simpleKeyValueStorage.readStringDataForKey(LanguageRepository.KEY_DEFAULT_LANGUAGE)
        }
    }

    override suspend fun getPreviousLanguage(): String? {
        return withContext(dispatcher) {
            simpleKeyValueStorage.readStringDataForKey(LanguageRepository.KEY_PREVIOUS_LANGUAGE)
        }
    }
}

==> openbot-1.0.9-sources.jar: ai/engagely/openbot/model/repositories/impl/AppLanguageRepository.kt <==
package ai.engagely.openbot.model.repositories.impl

import ai.engagely.openbot.model.localstorage.SimpleKeyValueStorage
import ai.engagely.openbot.model.repositories.LanguageRepository
import kotlinx.coroutines.CoroutineDispatcher
import kotlinx.coroutines.withContext

class AppLanguageRepository(
    private val dispatcher: CoroutineDispatcher,
    private val simpleKeyValueStorage: SimpleKeyValueStorage
) : LanguageRepository {

    override suspend fun setDefaultLanguage(languageCode: String) {
        withContext(dispatcher) {
            simpleKeyValueStorage.storeStringDataForKey(
                KEY_DEFAULT_LANGUAGE,
                languageCode
            )
        }
    }

    override suspend fun setCurrentLanguage(languageCode: String) {
        withContext(dispatcher) {
            updatePreviousWithCurrent()
            simpleKeyValueStorage.storeStringDataForKey(
                KEY_CURRENT_LANGUAGE,
                languageCode
            )
        }
    }

    override suspend fun updatePreviousWithCurrent() {
        getCurrentLanguage()?.let { currentLanguage ->
            simpleKeyValueStorage.storeStringDataForKey(
                KEY_PREVIOUS_LANGUAGE,
                currentLanguage
            )
        }
    }

    override suspend fun getCurrentLanguage(): String? {
        return withContext(dispatcher) {
            simpleKeyValueStorage.readStringDataForKey(KEY_CURRENT_LANGUAGE)
                ?: simpleKeyValueStorage.readStringDataForKey(KEY_DEFAULT_LANGUAGE)
        }
    }

    override suspend fun getPreviousLanguage(): String? {
        return withContext(dispatcher) {
            simpleKeyValueStorage.readStringDataForKey(KEY_PREVIOUS_LANGUAGE)
        }
    }

    companion object {
        const val KEY_DEFAULT_LANGUAGE = "default_language"
        const val KEY_CURRENT_LANGUAGE = "current_language"
        const val KEY_PREVIOUS_LANGUAGE = "previous_language"
    }
}
